
/* 
 * Copyright (c) 1993-2005 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/


#ifndef jloco_TCLSERV_CLIENT_ERROR_H
#define jloco_TCLSERV_CLIENT_ERROR_H

#include <server/jlocoError.h>

/* -- MODULES ERRORS -------------------------------------------------- */

enum jloco_error {
	E_jloco_OK					  			= 0,

	/* module errors */
	E_jloco_INVALID_GYRO_MODE              = S_jloco_INVALID_GYRO_MODE,
	E_jloco_POS_TRACKING_ON                = S_jloco_POS_TRACKING_ON,
	E_jloco_POSITIVE_VALUE_EXPECTED        = S_jloco_POSITIVE_VALUE_EXPECTED,
	E_jloco_POSTER_READ_FAILED             = S_jloco_POSTER_READ_FAILED,
	E_jloco_INTERNAL_ERROR                 = S_jloco_INTERNAL_ERROR,
	E_jloco_POSTER_NOT_UPDATED             = S_jloco_POSTER_NOT_UPDATED,
	E_jloco_INTERNAL_INTERRUPT             = S_jloco_INTERNAL_INTERRUPT,
	E_jloco_BAD_REF                        = S_jloco_BAD_REF,
	E_jloco_POSTER_NOT_FOUND               = S_jloco_POSTER_NOT_FOUND,
	E_jloco_SIGACTION_ERROR                = S_jloco_SIGACTION_ERROR,
	E_jloco_BATTERY_LOW                    = S_jloco_BATTERY_LOW,
	E_jloco_INVALID_TRACK_MODE             = S_jloco_INVALID_TRACK_MODE,
	E_jloco_MOTOR_READ_ERROR               = S_jloco_MOTOR_READ_ERROR,
	E_jloco_JOYSTICK_ERROR                 = S_jloco_JOYSTICK_ERROR,
	E_jloco_MOTOR_ERROR                    = S_jloco_MOTOR_ERROR,
	E_jloco_NEOBOTIX_ERROR                 = S_jloco_NEOBOTIX_ERROR,


	/* std errors */
	E_jloco_ACTIVITY_INTERRUPTED           = S_jloco_stdGenoM_ACTIVITY_INTERRUPTED,
	E_jloco_TOO_MANY_ACTIVITIES            = S_jloco_stdGenoM_TOO_MANY_ACTIVITIES,
	E_jloco_ACTIVITY_FAILED                = S_jloco_stdGenoM_ACTIVITY_FAILED,
	E_jloco_WAIT_ABORT_ZOMBIE_ACTIVITY     = S_jloco_stdGenoM_WAIT_ABORT_ZOMBIE_ACTIVITY,
	E_jloco_UNKNOWN_ACTIVITY               = S_jloco_stdGenoM_UNKNOWN_ACTIVITY,
	E_jloco_FORBIDDEN_ACTIVITY_TRANSITION  = S_jloco_stdGenoM_FORBIDDEN_ACTIVITY_TRANSITION,
	E_jloco_SYSTEM_ERROR                   = S_jloco_stdGenoM_SYSTEM_ERROR,
	E_jloco_ACTIVITY_ALREADY_ENDED         = S_jloco_stdGenoM_ACTIVITY_ALREADY_ENDED,
	E_jloco_WAIT_INIT_RQST                 = S_jloco_stdGenoM_WAIT_INIT_RQST,
	E_jloco_CONTROL_CODEL_ERROR            = S_jloco_stdGenoM_CONTROL_CODEL_ERROR,
	E_jloco_EXEC_TASK_SUSPENDED            = S_jloco_stdGenoM_EXEC_TASK_SUSPENDED,
	E_jloco_BAD_BLOCK_TYPE                 = S_jloco_stdGenoM_BAD_BLOCK_TYPE,
	E_jloco_BAD_POSTER_TYPE                = S_jloco_stdGenoM_BAD_POSTER_TYPE,

};

typedef enum jloco_error jloco_error_t;

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Take an error string in parameter, and try to get the error index associated
 * to this string
 * Returns -1 in failure case (and err is not set)
 * Returns 0 in success case (and err has a sensitive value)
 */
int jloco_decode_error(const char* str, int *err);

/*
 * Take an integer representing an error, and try to get its textual
 * representation, in the jloco context.
 *
 * Returns NULL in case of failure
 */
const char* jloco_error_str(int err);

#ifdef __cplusplus
}
#endif


/*-------------------------- end file loading ---------------------------*/
#endif
